package Alien::libdwarf;
use 5.012;

our $VERSION = "20200114.1";

=head1 NAME

Alien::libdwarf - [deprecated] DWARF debugging information

=cut

=head1 DESCRIPTION

Deprecated/renamed in the sake of L<XS::libdwarf>.

=head1 SYNOPSIS

=head1 AUTHOR

Ivan Baidakou <dmol@cpan.org>, Crazy Panda LTD

=head1 LICENSE

You may distribute this code under the same terms as Perl itself.

=cut


1;
